test

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrCannotReadDir = errors.New("cannot read directory")
	ErrGoModNotFound = errors.New("could not find go.mod")
)

Functions

This section is empty.

Types

type Config

type Config struct {
	AbsolutePath string
	TestPath     string
}

Config is the representation of a test config.

type Node

type Node struct {
	Value   any            `json:"value,omitempty"`
	Type    string         `json:"type"`
	Details map[string]any `json:"details,omitempty"`
	Nodes   []*Node        `json:"nodes,omitempty"`
}

type PaperTest

type PaperTest struct {
	// contains filtered or unexported fields
}

PaperTest is the unit test instance.

func New

func New(t *testing.T) *PaperTest

New creates the PaperTest instance to unit tests.

func (*PaperTest) Assert

func (m *PaperTest) Assert(structure *node.Node[core.Structure]) *PaperTest

Assert validates if the structure is the same as defined by Equals method.

func (*PaperTest) Equals

func (m *PaperTest) Equals(file string) *PaperTest

Equals defines which file will be loaded to do the comparison.

Jump to